==> fwbuilder-2.1.11.tar.gz: fwbuilder-2.1.11/src/gui/instOptionsDialog.h <==
/* 

                          Firewall Builder

                 Copyright (C) 2006 NetCitadel, LLC

  Author:  Illiya Yalovoy <yalovoy@gmail.com>

  $Id: instOptionsDialog.h,v 1.3 2007/04/25 05:00:36 vkurland Exp $

  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#ifndef __INSTOPTIONSDIALOG_H_
#define __INSTOPTIONSDIALOG_H_

#include "config.h"
#include <instoptionsdialog_q.h>

class instOptionsDialog : public instOptionsDialog_q
{
    Q_OBJECT
 private:
    int delta_y;

 public:
    instOptionsDialog(QWidget *parent);
    virtual void closeEvent(QCloseEvent *e);

    QString getUName();
    QString getPWD();
    QString getEPWD();

    virtual QSize sizeHint() const;
    virtual QSize minimumSizeHint() const;

    virtual void hidePIXOptions();
    virtual void hideOption(QWidget *w);

public slots:
    virtual void applyChanges();
    virtual void discardChanges();
    virtual void updateRollback();
    
 signals:
/**
 * This signal is emitted from closeEvent, ObjectEditor connects
 * to this signal to make checks before the object editor can be closed
 * and to store its position on the screen
 */
   // void close_sign(QCloseEvent *e);
    
};

#endif

==> fwbuilder_2.1.19.orig.tar.gz: fwbuilder-2.1.19/src/gui/instOptionsDialog.h <==
/* 

                          Firewall Builder

                 Copyright (C) 2006 NetCitadel, LLC

  Author:  Illiya Yalovoy <yalovoy@gmail.com>

  $Id: instOptionsDialog.h,v 1.4 2007/05/11 02:14:30 vkurland Exp $

  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#ifndef __INSTOPTIONSDIALOG_H_
#define __INSTOPTIONSDIALOG_H_

#include "config.h"
#include <instoptionsdialog_q.h>

class instConf;

class instOptionsDialog : public instOptionsDialog_q
{
    Q_OBJECT
 private:
    int delta_y;
    instConf *cnf;
    
 public:
    instOptionsDialog(QWidget *parent, instConf *_cnf);

    QString getUName();
    QString getPWD();
    QString getEPWD();

 public slots:
    
 signals:
/**
 * This signal is emitted from closeEvent, ObjectEditor connects
 * to this signal to make checks before the object editor can be closed
 * and to store its position on the screen
 */
   // void close_sign(QCloseEvent *e);
    
};

#endif
